@@ -177,8 +177,20 @@ class Site:
 
             if collection.subcollections:
 
-                for subcollection in more_itertools.collapse(
-                        collection.get_subcollections.values()):
+                for subcollection_group in collection.get_subcollections():
+                    logging.info(f'{subcollection_group=}')
+
+                    _subcollection_group = collection.get_subcollections()[subcollection_group]
+                    sorted_group = sorted(
+                            _subcollection_group,
+                            key=lambda x:(len(x.pages), x.title),
+                            reverse=True,
+                            )
+
+
+                    for subcollection in sorted_group:
+
+                        self.subcollections[subcollection_group] = sorted_group
 
                         for archive in subcollection.archive:
                             self.route(archive)
@@ -205,6 +217,8 @@ class Site:
 
                 template_attrs = self.get_public_attributes(page)
 
+                # breakpoint()
+
                 content = engine.render(page, **template_attrs)
 
                 route = self.output_path.joinpath(page.routes[0].strip("/"))
